==> h2o-java-rest-bindings-3.2.0.9-sources.jar: water/bindings/pojos/NaiveBayesModelOutputV3.java <==
package water.bindings.pojos;

import java.util.Map;

public class NaiveBayesModelOutputV3 extends ModelOutputSchema {
    /** Categorical levels of the response */
    public String[] levels;

    /** A-priori probabilities of the response */
    public TwoDimTableV3 apriori;

    /** Conditional probabilities of the predictors */
    public TwoDimTableV3[] pcond;

    /** Column names */
    public String[] names;

    /** Domains for categorical (enum) columns */
    public String[][] domains;

    /** Cross-validation models (model ids) */
    public String[] cross_validation_models;

    /** Cross-validation predictions (frame ids) */
    public String[] cross_validation_predictions;

    /** Category of the model (e.g., Binomial) */
    public ModelCategory model_category;

    /** Model summary */
    public TwoDimTableV3 model_summary;

    /** Scoring history */
    public TwoDimTableV3 scoring_history;

    /** Training data model metrics */
    public ModelMetricsBase training_metrics;

    /** Validation data model metrics */
    public ModelMetricsBase validation_metrics;

    /** Cross-validation model metrics */
    public ModelMetricsBase cross_validation_metrics;

    /** Job status */
    public String status;

    /** Start time in milliseconds */
    public long start_time;

    /** End time in milliseconds */
    public long end_time;

    /** Runtime in milliseconds */
    public long run_time;

    /** Help information for output fields */
    public Map<String,String> help;
}

==> h2o-java-rest-bindings-3.8.0.5-sources.jar: water/bindings/pojos/NaiveBayesModelOutputV3.java <==
package water.bindings.pojos;

import java.util.Map;

public class NaiveBayesModelOutputV3 extends ModelOutputSchema {
    /** Categorical levels of the response */
    public String[] levels;

    /** A-priori probabilities of the response */
    public TwoDimTableV3 apriori;

    /** Conditional probabilities of the predictors */
    public TwoDimTableV3[] pcond;

    /** Column names */
    public String[] names;

    /** Domains for categorical columns */
    public String[][] domains;

    /** Cross-validation models (model ids) */
    public String[] cross_validation_models;

    /** Cross-validation predictions (frame ids) */
    public String[] cross_validation_predictions;

    /** Category of the model (e.g., Binomial) */
    public ModelCategory model_category;

    /** Model summary */
    public TwoDimTableV3 model_summary;

    /** Scoring history */
    public TwoDimTableV3 scoring_history;

    /** Training data model metrics */
    public ModelMetricsBase training_metrics;

    /** Validation data model metrics */
    public ModelMetricsBase validation_metrics;

    /** Cross-validation model metrics */
    public ModelMetricsBase cross_validation_metrics;

    /** Job status */
    public String status;

    /** Start time in milliseconds */
    public long start_time;

    /** End time in milliseconds */
    public long end_time;

    /** Runtime in milliseconds */
    public long run_time;

    /** Help information for output fields */
    public Map<String,String> help;
}
